@@ -1,5 +1,3 @@
-use std::f64::consts::PI;
-
 use projective::Projective;
 
 #[derive(Debug, Copy, Clone, PartialEq)]
@@ -21,5 +19,5 @@ fn test_transform() {
     assert_eq!(p0.translate(2.0, 1.0), Point(3.0, 3.0));
     assert_eq!(p0.scale(2.0, 3.0), Point(2.0, 6.0));
     // floating precision error, implement rotate manually to reduce errors
-    assert_eq!(p0.rotate(PI), Point(-0.9999999999999998, -2.0));
+    assert_eq!(p0.rotate(std::f64::consts::PI), Point(-0.9999999999999998, -2.0));
 }
